@@ -1,4 +1,3 @@
-# coding: utf-8
 # /*##########################################################################
 # Copyright (C) 2016-2021 European Synchrotron Radiation Facility
 #
@@ -26,8 +25,10 @@ Tests for the histogramnd function.
 Results are compared to numpy's histogramdd.
 """
 
+import os
 import unittest
 import operator
+import pytest
 
 import numpy as np
 
@@ -609,6 +610,40 @@ class _TestHistogramnd(unittest.TestCase):
                                     result_np_w_1[0].sum(dtype=np.float64)),
                         msg=self.state_msg)
 
+    @pytest.mark.usefixtures("use_large_memory")
+    def test_histo_big_array(self):
+        """
+        Test histogram on arrays with more than 2**31-1 samples.
+        """
+        if self.sample.ndim > 1:
+            self.skipTest("Test only many samples along one dimension")
+        if self.sample.dtype.itemsize > 4:
+            self.skipTest("Test only many samples for itemsize < 4")
+        n_repeat = (2**31 + 10) // self.sample.size
+        sample = np.repeat(self.sample, n_repeat)
+        n_bins = int(1e6)
+        result_c = histogramnd(
+            sample,
+            self.histo_range,
+            n_bins,
+            last_bin_closed=True
+        )
+        result_np = np.histogramdd(
+            sample,
+            n_bins,
+            range=self.histo_range
+        )
+        for i_edges, edges in enumerate(result_c[2]):
+            self.assertTrue(
+                np.allclose(
+                    edges,
+                    result_np[1][i_edges]
+                ),
+                msg='{0}. Testing bin_edges for dim {1}.'''.format(self.state_msg, i_edges+1)
+            )
+
+
+
 
 class _TestHistogramnd_1d(_TestHistogramnd):
     """
